spedecon_gtwidConstructor for class spedecon_gtwid. Use helper functions gaussian_gtwid(), laplace_gtwid(), and uniform_gtwid() instead whenever possible.
new_spedecon_gtwid(gtwid, family)Object of class spedecon_gtwid
Function representing the Fourier transform
List with at least one entry family[["family"]] naming the family of distributions, and possibly other entries stating the values of the parameters in that family.
The spedecon_gtwid class is meant to represent the Fourier transform of a probability density.
The basic type is a function.
It also has a family attribute which can hold the name and parameters of the family of distributions.
Use gaussian_gtwid(), laplace_gtwid(), or uniform_gtwid() instead whenever possible.