spedecon_spline_sped_fitInternal use only. Constructor for class spedecon_spline_sped_fit
new_spedecon_spline_sped_fit(coef, basis, alpha, constraint)Object of class spedecon_spline_sped_fit
Numeric vector; the coefficients of the spline.
Object of class spedecon_spline_basis, representing a basis for the spline space.
Positive numeric, the alpha that was used for the fit.
The type of constraint used.
The basic type of an object of type spedecon_spline_sped_fit is a function; one can therefore evaluate, plot, etc. and ignore the other attributes if desired.
The function is represented as a spline, and has attributes coef and basis, which represents the coefficients and basis respectively.
coef is a numeric vector, while basis is an object of class spedecon_spline_basis, which is essentially just a list holding the knots and order of the spline space.
A spedecon_spline_sped_fit object also has attributes alpha and constraint which record the penalty parameter and constraint method used for the fit.